@@ -54,7 +54,7 @@ class Exceptions:
 
 class STSClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/sts.html#STS.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sts.html#STS.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html)
     """
 
@@ -66,10 +66,10 @@ class STSClient:
         *,
         RoleArn: str,
         RoleSessionName: str,
-        PolicyArns: List[PolicyDescriptorTypeTypeDef] = None,
+        PolicyArns: List["PolicyDescriptorTypeTypeDef"] = None,
         Policy: str = None,
         DurationSeconds: int = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
         TransitiveTagKeys: List[str] = None,
         ExternalId: str = None,
         SerialNumber: str = None,
@@ -77,7 +77,10 @@ class STSClient:
         SourceIdentity: str = None
     ) -> AssumeRoleResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/sts.html#STS.Client.assume_role)
+        Returns a set of temporary security credentials that you can use to access AWS
+        resources that you might not normally have access to.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sts.html#STS.Client.assume_role)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role)
         """
 
@@ -87,12 +90,15 @@ class STSClient:
         RoleArn: str,
         PrincipalArn: str,
         SAMLAssertion: str,
-        PolicyArns: List[PolicyDescriptorTypeTypeDef] = None,
+        PolicyArns: List["PolicyDescriptorTypeTypeDef"] = None,
         Policy: str = None,
         DurationSeconds: int = None
     ) -> AssumeRoleWithSAMLResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/sts.html#STS.Client.assume_role_with_saml)
+        Returns a set of temporary security credentials for users who have been
+        authenticated via a SAML authentication response.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sts.html#STS.Client.assume_role_with_saml)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role_with_saml)
         """
 
@@ -103,18 +109,23 @@ class STSClient:
         RoleSessionName: str,
         WebIdentityToken: str,
         ProviderId: str = None,
-        PolicyArns: List[PolicyDescriptorTypeTypeDef] = None,
+        PolicyArns: List["PolicyDescriptorTypeTypeDef"] = None,
         Policy: str = None,
         DurationSeconds: int = None
     ) -> AssumeRoleWithWebIdentityResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
+        Returns a set of temporary security credentials for users who have been
+        authenticated in a mobile or web application with a web identity provider.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role_with_web_identity)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/sts.html#STS.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sts.html#STS.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#can_paginate)
         """
 
@@ -122,7 +133,10 @@ class STSClient:
         self, *, EncodedMessage: str
     ) -> DecodeAuthorizationMessageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/sts.html#STS.Client.decode_authorization_message)
+        Decodes additional information about the authorization status of a request from
+        an encoded message returned in response to an AWS request.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sts.html#STS.Client.decode_authorization_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#decode_authorization_message)
         """
 
@@ -134,19 +148,26 @@ class STSClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/sts.html#STS.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sts.html#STS.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#generate_presigned_url)
         """
 
     def get_access_key_info(self, *, AccessKeyId: str) -> GetAccessKeyInfoResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/sts.html#STS.Client.get_access_key_info)
+        Returns the account identifier for the specified access key ID.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sts.html#STS.Client.get_access_key_info)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_access_key_info)
         """
 
     def get_caller_identity(self) -> GetCallerIdentityResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/sts.html#STS.Client.get_caller_identity)
+        Returns details about the IAM user or role whose credentials are used to call
+        the operation.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sts.html#STS.Client.get_caller_identity)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_caller_identity)
         """
 
@@ -155,12 +176,15 @@ class STSClient:
         *,
         Name: str,
         Policy: str = None,
-        PolicyArns: List[PolicyDescriptorTypeTypeDef] = None,
+        PolicyArns: List["PolicyDescriptorTypeTypeDef"] = None,
         DurationSeconds: int = None,
-        Tags: List[TagTypeDef] = None
+        Tags: List["TagTypeDef"] = None
     ) -> GetFederationTokenResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/sts.html#STS.Client.get_federation_token)
+        Returns a set of temporary security credentials (consisting of an access key ID,
+        a secret access key, and a security token) for a federated user.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sts.html#STS.Client.get_federation_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_federation_token)
         """
 
@@ -168,6 +192,8 @@ class STSClient:
         self, *, DurationSeconds: int = None, SerialNumber: str = None, TokenCode: str = None
     ) -> GetSessionTokenResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/sts.html#STS.Client.get_session_token)
+        Returns a set of temporary credentials for an AWS account or IAM user.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sts.html#STS.Client.get_session_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_session_token)
         """
